@@ -27,7 +27,22 @@ INSTALLED_APPS = [
     'django.contrib.auth',
     'django.contrib.contenttypes',
     'imagekit',
-    'core',
+    'tests',
+    'django_nose',
+]
+
+TEST_RUNNER = 'django_nose.NoseTestSuiteRunner'
+NOSE_ARGS = [
+    '-s',
+    '--with-progressive',
+
+    # When the tests are run --with-coverage, these args configure coverage
+    # reporting (requires coverage to be installed).
+    # Without the --with-coverage flag, they have no effect.
+    '--cover-tests',
+    '--cover-html',
+    '--cover-package=imagekit',
+    '--cover-html-dir=%s' % os.path.join(BASE_PATH, 'cover')
 ]
 
 DEBUG = True
